@@ -113,11 +113,11 @@ def create_element(cell_type, element_type, order, **kwargs):
 
         Supported values:
         Lagrange, P,
-        discontinuous Lagrange, dP, DP,
         vector Lagrange, vP,
-        vector discontinuous Lagrange, vdP, vDP,
-        matrix discontinuous Lagrange,
-        symmetric matrix discontinuous Lagrange,
+        matrix Lagrange,
+        symmetric matrix Lagrange,
+        dPc,
+        vector dPc,
         Crouzeix-Raviart, CR, Crouzeix-Falk, CF,
         conforming Crouzeix-Raviart, conforming CR,
         serendipity, S,
@@ -130,7 +130,6 @@ def create_element(cell_type, element_type, order, **kwargs):
         Raviart-Thomas, RT, N1div,
         Brezzi-Douglas-Marini, BDM, N2div,
         Q,
-        dQ,
         vector Q, vQ,
         NCE, RTCE, Qcurl,
         NCF, RTCF, Qdiv,
@@ -140,7 +139,7 @@ def create_element(cell_type, element_type, order, **kwargs):
         Mardal-Tai-Winther, MTW,
         Argyris,
         bubble,
-        dual,
+        dual polynomial, dual P, dual,
         Buffa-Christiansen, BC,
         rotated Buffa-Christiansen, RBC,
         Brezzi-Douglas-Fortin-Marini, BDFM,
@@ -161,7 +160,14 @@ def create_element(cell_type, element_type, order, **kwargs):
         Wu-Xu,
         transition,
         Guzman-Neilan,
-        nonconforming Arnold-Winther, nonconforming AW
+        nonconforming Arnold-Winther, nonconforming AW,
+        TScurl, trimmed serendipity Hcurl,
+        TSdiv, trimmed serendipity Hdiv,
+        TNT, tiniest tensor,
+        TNTcurl, tiniest tensor Hcurl,
+        TNTdiv, tiniest tensor Hdiv,
+        Arnold-Boffi-Falk, ABF,
+        Arbogast-Correa, AC, AC full, Arbogast-Correa full
     order : int
         The order of the element.
     """
