@@ -51,38 +51,6 @@ class Lagrange(CiarletElement):
     continuity = "C0"
 
 
-class DiscontinuousLagrange(CiarletElement):
-    """Discontinuous Lagrange finite element."""
-
-    def __init__(self, reference, order, variant="equispaced"):
-        if order == 0:
-            dofs = [
-                PointEvaluation(
-                    tuple(sympy.Rational(1, reference.tdim + 1) for i in range(reference.tdim)),
-                    entity=(reference.tdim, 0))]
-        else:
-            points, _ = get_quadrature(variant, order + 1)
-
-            dofs = []
-            for i in product(range(order + 1), repeat=reference.tdim):
-                if sum(i) <= order:
-                    point = tuple(sympy.Rational(j, order) for j in i[::-1])
-                    dofs.append(PointEvaluation(point, entity=(reference.tdim, 0)))
-        super().__init__(
-            reference, order, polynomial_set(reference.tdim, 1, order), dofs, reference.tdim, 1
-        )
-        self.variant = variant
-
-    def init_kwargs(self):
-        """Return the kwargs used to create this element."""
-        return {"variant": self.variant}
-
-    names = ["discontinuous Lagrange", "dP", "DP"]
-    references = ["interval", "triangle", "tetrahedron", "quadrilateral", "hexahedron"]
-    min_order = 0
-    continuity = "L2"
-
-
 class VectorLagrange(CiarletElement):
     """Vector Lagrange finite element."""
 
@@ -119,47 +87,11 @@ class VectorLagrange(CiarletElement):
     continuity = "C0"
 
 
-class VectorDiscontinuousLagrange(CiarletElement):
-    """Vector Lagrange finite element."""
-
-    def __init__(self, reference, order, variant="equispaced"):
-        scalar_space = DiscontinuousLagrange(reference, order, variant)
-        dofs = []
-        if reference.tdim == 1:
-            directions = [1]
-        else:
-            directions = [
-                tuple(1 if i == j else 0 for j in range(reference.tdim))
-                for i in range(reference.tdim)
-            ]
-        for p in scalar_space.dofs:
-            for d in directions:
-                dofs.append(DotPointEvaluation(p.point, d, entity=p.entity))
-
-        super().__init__(
-            reference, order,
-            polynomial_set(reference.tdim, reference.tdim, order),
-            dofs,
-            reference.tdim,
-            reference.tdim,
-        )
-        self.variant = variant
-
-    def init_kwargs(self):
-        """Return the kwargs used to create this element."""
-        return {"variant": self.variant}
-
-    names = ["vector discontinuous Lagrange", "vdP", "vDP"]
-    references = ["interval", "triangle", "tetrahedron", "quadrilateral", "hexahedron"]
-    min_order = 0
-    continuity = "L2"
-
-
-class MatrixDiscontinuousLagrange(CiarletElement):
+class MatrixLagrange(CiarletElement):
     """Matrix Lagrange finite element."""
 
     def __init__(self, reference, order, variant="equispaced"):
-        scalar_space = DiscontinuousLagrange(reference, order, variant)
+        scalar_space = Lagrange(reference, order, variant)
         dofs = []
         if reference.tdim == 1:
             directions = [1]
@@ -186,13 +118,13 @@ class MatrixDiscontinuousLagrange(CiarletElement):
         """Return the kwargs used to create this element."""
         return {"variant": self.variant}
 
-    names = ["matrix discontinuous Lagrange"]
-    references = ["triangle", "tetrahedron", "quadrilateral", "hexahedron"]
+    names = ["matrix Lagrange"]
+    references = ["triangle", "tetrahedron"]
     min_order = 0
     continuity = "L2"
 
 
-class SymmetricMatrixDiscontinuousLagrange(CiarletElement):
+class SymmetricMatrixLagrange(CiarletElement):
     """Symmetric matrix Lagrange finite element."""
 
     def __init__(self, reference, order, variant="equispaced"):
@@ -215,7 +147,7 @@ class SymmetricMatrixDiscontinuousLagrange(CiarletElement):
                           (0, 0, 0, 0, 0, 1, 0, 0, 0),
                           (0, 0, 0, 0, 0, 0, 0, 0, 1)]
 
-        scalar_space = DiscontinuousLagrange(reference, order, variant)
+        scalar_space = Lagrange(reference, order, variant)
         dofs = []
         for p in scalar_space.dofs:
             for d in directions:
@@ -234,7 +166,7 @@ class SymmetricMatrixDiscontinuousLagrange(CiarletElement):
         """Return the kwargs used to create this element."""
         return {"variant": self.variant}
 
-    names = ["symmetric matrix discontinuous Lagrange"]
-    references = ["triangle", "tetrahedron", "quadrilateral", "hexahedron"]
+    names = ["symmetric matrix Lagrange"]
+    references = ["triangle", "tetrahedron"]
     min_order = 0
     continuity = "L2"
