@@ -3,13 +3,11 @@ import numpy as np
 import pytest
 
 elements = {
-    "interval": [("P", "Lagrange", range(1, 4), ["equispaced"]),
-                 ("dP", "Discontinuous Lagrange", range(1, 4), []),
+    "interval": [("P", "Lagrange", range(1, 4), [("LagrangeVariant", "equispaced")]),
                  ("serendipity", "Serendipity", range(1, 5), []),
                  ("bubble", "Bubble", range(2, 5), []),
-                 ("dP", "DPC", range(0, 5), [])],
-    "triangle": [("P", "Lagrange", range(1, 4), ["equispaced"]),
-                 ("dP", "Discontinuous Lagrange", range(1, 4), []),
+                 ("dPc", "DPC", range(0, 5), [("bool", True)])],
+    "triangle": [("P", "Lagrange", range(1, 4), [("LagrangeVariant", "equispaced")]),
                  ("bubble", "Bubble", range(3, 5), []),
                  ("N1curl", "Nedelec 1st kind H(curl)", range(1, 4), []),
                  ("N2curl", "Nedelec 2nd kind H(curl)", range(1, 4), []),
@@ -17,8 +15,7 @@ elements = {
                  ("N2div", "Brezzi-Douglas-Marini", range(1, 4), []),
                  ("Regge", "Regge", range(0, 4), []),
                  ("Crouzeix-Raviart", "Crouzeix-Raviart", [1], [])],
-    "tetrahedron": [("P", "Lagrange", range(1, 4), ["equispaced"]),
-                    ("dP", "Discontinuous Lagrange", range(1, 4), []),
+    "tetrahedron": [("P", "Lagrange", range(1, 4), [("LagrangeVariant", "equispaced")]),
                     ("bubble", "Bubble", range(4, 6), []),
                     ("N1curl", "Nedelec 1st kind H(curl)", range(1, 4), []),
                     ("N2curl", "Nedelec 2nd kind H(curl)", range(1, 3), []),
@@ -26,22 +23,20 @@ elements = {
                     ("N2div", "Brezzi-Douglas-Marini", range(1, 3), []),
                     ("Regge", "Regge", range(0, 3), []),
                     ("Crouzeix-Raviart", "Crouzeix-Raviart", [1], [])],
-    "quadrilateral": [("Q", "Lagrange", range(1, 4), ["equispaced"]),
-                      ("dQ", "Discontinuous Lagrange", range(1, 4), []),
-                      ("dP", "DPC", range(0, 4), []),
+    "quadrilateral": [("Q", "Lagrange", range(1, 4), [("LagrangeVariant", "equispaced")]),
+                      ("dPc", "DPC", range(0, 4), [("bool", True)]),
                       ("serendipity", "Serendipity", range(1, 5), []),
                       ("Qdiv", "Raviart-Thomas", range(1, 4), []),
                       ("Qcurl", "Nedelec 1st kind H(curl)", range(1, 4), []),
                       ("Sdiv", "Brezzi-Douglas-Marini", range(1, 4), []),
                       ("Scurl", "Nedelec 2nd kind H(curl)", range(1, 4), [])],
-    "hexahedron": [("Q", "Lagrange", range(1, 3), ["equispaced"]),
-                   ("dQ", "Discontinuous Lagrange", range(1, 3), []),
+    "hexahedron": [("Q", "Lagrange", range(1, 3), [("LagrangeVariant", "equispaced")]),
                    ("serendipity", "Serendipity", range(1, 5), []),
                    ("Qdiv", "Raviart-Thomas", range(1, 3), []),
                    ("Qcurl", "Nedelec 1st kind H(curl)", range(1, 3), []),
                    ("Sdiv", "Brezzi-Douglas-Marini", range(1, 3), []),
                    ("Scurl", "Nedelec 2nd kind H(curl)", range(1, 3), [])],
-    "prism": [("Lagrange", "Lagrange", range(1, 4), ["equispaced"])]
+    "prism": [("Lagrange", "Lagrange", range(1, 4), [("LagrangeVariant", "equispaced")])]
 }
 
 
@@ -53,7 +48,6 @@ def to_float(a):
 
 
 def make_lattice(cell, N=3):
-    import numpy as np
     if cell == "interval":
         return np.array([[i / N] for i in range(N + 1)])
     if cell == "triangle":
@@ -99,13 +93,21 @@ def test_against_basix(has_basix, elements_to_test, cells_to_test, cell, symfem_
     points = make_lattice(cell, 2)
     parsed_args = []
     for a in args:
-        parsed_args.append(basix.lattice.string_to_type(a))
+        if a[0] == "LagrangeVariant":
+            parsed_args.append(basix.variants.string_to_lagrange_variant(a[1]))
+        elif a[0] == "bool":
+            parsed_args.append(a[1])
+        else:
+            raise ValueError(f"Unknown arg type: {a[0]}")
     space = basix.create_element(
         basix.finite_element.string_to_family(basix_type, cell),
         basix.cell.string_to_type(cell), order, *parsed_args)
     result = space.tabulate(0, points)[0]
 
     element = create_element(cell, symfem_type, order)
-    sym_result = element.tabulate_basis(points, "xxyyzz", symbolic=False, use_legendre=True)
+    sym_result = element.tabulate_basis(points, "xyz,xyz", symbolic=False, use_legendre=True)
+
+    if len(result.shape) != len(sym_result.shape):
+        sym_result = sym_result.reshape(result.shape)
 
     assert np.allclose(result, sym_result)
